@@ -137,7 +137,7 @@ def find_groups_from_starting_group(
 
 
 def score_full_path(
-    path: list,
+    path: list[str],
     binarized_groups: csr_matrix,
     binarized_target_group: csr_matrix,
     scaled_utility_vector: np.ndarray,
@@ -179,6 +179,7 @@ def score_full_path(
     
     result = Result(
         score,
+        path,
         matching_percent,
         matching_users,
         matching_users_count,
@@ -187,7 +188,6 @@ def score_full_path(
         extraneous_users_count,
         unmatched_users,
         unmatched_users_count,
-        path
     )
 
     return result
